@@ -331,7 +331,7 @@ class FMQLReplyStore:
             def currentReplyFile(self):
                 return self.__currentReplyFile
                                         
-            def next(self):
+            def __next__(self):
         
                 for typ in sorted(self.__flsByTyp, key=lambda x: float(re.sub("_", ".", x))):
                 
@@ -392,7 +392,7 @@ class FilteredResultIterator:
         return self._numberFiltered
             
     def __iter__(self):
-        for reply in self.__replyIter.next():
+        for reply in next(self.__replyIter):
             for resource in reply["results"]:
                 if self.__filt and not self.__filt(resource):
                     self._numberFiltered += 1
@@ -773,7 +773,7 @@ def recacheForCSTOPs(stationNo, typId, fmqlIF, flushToRF=True):
     noRecachedStoppedResources = 0
     noRepliesWithStoppedResources = 0
     v2FromV1 = V1RecordToV2(forMongo=True)
-    for i, reply in enumerate(replyIter.next(), 1):
+    for i, reply in enumerate(next(replyIter), 1):
         replyFile = replyIter.currentReplyFile()
         replyHasStoppedResources = False
         nresults = []
@@ -870,11 +870,11 @@ def fix24DateTime(dtStr):
         return dtStr
     try:
         dt = datetime.strptime(dtStr.split("T")[0], "%Y-%m-%d")
-    except: # don't fix
+    except: # don't fix - may be issue as leads to problem above or bad time TODO
         return dtStr
     dt = dt + timedelta(days=1)
     dtStr = datetime.strftime(dt, "%Y-%m-%dT%H:%M:%SZ")
-    return unicode(dtStr)
+    return dtStr
     
 """
 FM's trailing number implies 0 for time so .1 = 10 o clock or
@@ -964,7 +964,7 @@ def flip(stationNo, typId, multipleProp, multipleTypId, multipleTypName, explici
     ptUpProp = "{}_container_".format(multipleProp)
     cntMultipleProp = "{}_count_".format(multipleProp) # adding in counter to parent for mult
     noResourcesWOMultiple = 0
-    for i, reply in enumerate(replyIter.next(), 1):
+    for i, reply in enumerate(next(replyIter), 1):
         replyFile = replyIter.currentReplyFile()
         reply["lessResults"] = []
         for resource in reply["results"]:
@@ -1086,12 +1086,12 @@ import sys
 def main():
 
     # zipAllRepliesByType("/data/vista/999/DataV1/")
-    return
+    # return
     
     replyStore = FMQLReplyStore("/data/vista/999/Data/")
     flTyp = "80"
     iter = replyStore.iterator(onlyTypes=["80"])
-    for flJSON in iter.next():
+    for flJSON in next(iter):
         print("First {}".format(len(flJSON["results"])))
         break
     lastReplyOfType = replyStore.lastReplyOfType("80")
